Blender Git Commit Log

All Blender Git commits.

Page: 4060 / 8462

February 8, 2017, 19:26 (GMT)
Various minor fixes & tweaks.
February 8, 2017, 16:32 (GMT)
Cycles Denoising: Use device-independent denoising in the CPUDevice
February 8, 2017, 16:32 (GMT)
Cycles Denoising: Implement device-independent denoising algorithm to deduplicate device code

Instead of implementing the full algorithm inside the device, the new code just calls the device in order to run specific kernels while handling all the high-level logic outside of the individual devices.
February 8, 2017, 15:39 (GMT)
Cleanup: warnings
February 8, 2017, 15:25 (GMT)
Fix uninitialized var with FOREACH_SCENE_OBJECT
February 8, 2017, 15:06 (GMT)
Fix breakage when saving files from the UI

The problem was with offscreen buffer rendering
February 8, 2017, 15:05 (GMT)
create BKE_scene_layer_active
February 8, 2017, 14:38 (GMT)
Some naive solution to avoid running 'generate auto override' code too often.

Proper solution will come later (probably based on some background job
or so...).
February 8, 2017, 13:50 (GMT)
Blender 2.78b: Point addons to an updated revision
February 8, 2017, 13:44 (GMT)
Bring back Lasso and Circle selection back

(and replace more instances of BaseLegacy/scene->base with Base/sl->object_bases)

Still need mouse selection, box selection, and menu selection

Also, there is still a problem with BA_WAS_SEL, at the moment only the
objects centers are highlighted.
February 8, 2017, 13:00 (GMT)
Cycles: Fix regression with transparent shadows in volume
February 8, 2017, 13:00 (GMT)
Cycles: Solve speed regression by casting opaque ray first
February 8, 2017, 13:00 (GMT)
Cycles: Fix compilation error on OpenCL
February 8, 2017, 13:00 (GMT)
Cycles: Split shadow functions to avoid some duplicated calculations
February 8, 2017, 13:00 (GMT)
Cycles: Store shadow intersections in the kernel globals

Seems CUDA failed to de-duplicate the array across multiple inlined
versions of the shadow_blocked(). Helped it a bit with that now.

Gives about 100MB memory improvement on a scenes after previous
commit and brings up memory "regression" to only 100MB comparing to
the master branch now.
February 8, 2017, 13:00 (GMT)
Cycles: Speedup transparent shadows on CUDA

This commit enables record-all behavior of transparent shadows
rays.

Render times difference goes as following:

GTX 1080 render time
BMW -0.5%
Fishy Cat -0.0%
Pabellon Barcelona -11.6%
Classroom +1.2%
Koro -58.6%

Kernel will now use some extra VRAM memory to store the intersection
array (200MB on my configuration). This we can optimize out with some
further commits.
February 8, 2017, 13:00 (GMT)
Cycles: Implement record-all transparent shadow function for GPU

The idea is to record all possible transparent intersections when
shooting transparent ray on GPU (similar to what we were doing on
CPU already).

This avoids need of doing whole ray-to-scene intersections queries
for each intersection and speeds up a lot cases like transparent
hair in the cost of extra memory.

This commit is a base ground for now and this feature is kept
disabled for until some further tweaks.
February 8, 2017, 13:00 (GMT)
Cycles: Use an utility function to sort intersections array
February 8, 2017, 13:00 (GMT)
Cycles: Make GPU version of shadow_blocked() closer to CPU

Now we break the traversal cycle and then perform volume attenuation
and check with zero throughput. Not sure it makes any measurable sense
at this moment, but in the future it might help de-duplicating some
extra logic here.
February 8, 2017, 13:00 (GMT)
Cycles: De-duplicate transparent shadows attenuation

Fair amount of code was duplicated for CPU and GPU, now we are
using inlined function to avoid such duplication.
By: Miika HämäläinenLast update: Nov-07-2014 14:18MiikaHweb | 2003-2021